@@ -18,7 +18,7 @@ Returns the IP address of the hostname.
 
 =head1 AUTHOR
 
-Tom Insam <tom@jerakeen.org>
+Mario Domgoergen <mdom@cpan.org>
 
 This program is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
